diff src/http/ngx_http.c @ 158:2d15b82126ed NGINX_0_3_26

nginx 0.3.26 *) Change: the "optimize_host_names" directive was renamed to the "optimize_server_names". *) Bugfix: if in the "proxy_pass" directive was no the URI part, then the main request URI was transferred to a backend while proxying the SSI subrequest.
author Igor Sysoev <http://sysoev.ru>
date Fri, 03 Feb 2006 00:00:00 +0300
parents 396dbbc06dd7
children 6be073125f2e
line wrap: on
line diff
--- a/src/http/ngx_http.c
+++ b/src/http/ngx_http.c
@@ -535,7 +535,7 @@ ngx_http_block(ngx_conf_t *cf, ngx_comma
          * check whether all name-based servers have the same configuraiton
          *     as the default server,
          * or some servers restrict the host names,
          * or some servers disable optimizing the host names
          */
 
         in_addr = in_port[p].addrs.elts;
@@ -545,7 +545,7 @@ ngx_http_block(ngx_conf_t *cf, ngx_comma
             for (s = 0; s < in_addr[a].names.nelts; s++) {
 
                 if (in_addr[a].core_srv_conf != name[s].core_srv_conf
-                    || name[s].core_srv_conf->optimize_host_names == 0
+                    || name[s].core_srv_conf->optimize_server_names == 0
                     || name[s].core_srv_conf->restrict_host_names
                        != NGX_HTTP_RESTRICT_HOST_OFF)
                 {
@@ -557,7 +557,7 @@ ngx_http_block(ngx_conf_t *cf, ngx_comma
              * if all name-based servers have the same configuration
              *         as the default server,
              *     and no servers restrict the host names,
              *     and no servers disable optimizing the host names
              * then we do not need to check them at run-time at all
              */
@@ -535,7 +535,7 @@ ngx_http_block(ngx_conf_t *cf, ngx_comma
          *     as the default server,
          * or some servers restrict the host names,
-         * or some servers disable optimizing the host names
+         * or some servers disable optimizing the server names
          */
 
@@ -557,7 +557,7 @@ ngx_http_block(ngx_conf_t *cf, ngx_comma
              *         as the default server,
              *     and no servers restrict the host names,
-             *     and no servers disable optimizing the host names
+             *     and no servers disable optimizing the server names
              * then we do not need to check them at run-time at all
              */